@@ -1,4 +1,4 @@
-# $Id: Generator.pm 18 2005-08-17 10:20:53Z daisuke $
+# $Id: Generator.pm 20 2005-10-18 09:41:09Z daisuke $
 #
 # Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -61,3 +61,38 @@ sub add_item
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+XML::RSS::LibXML::Genrator - Provide API to Generate XML::RSS::LibXML
+
+=head1 SYNOPSIS
+
+  use XML::RSS::LibXML;
+  use XML::RSS::LibXML::Genrator;
+
+  my $rss = XML::RSS::LibXMl->new;
+  my $g   = XML::RSS::LibXML::Generator->new;
+
+=head1 METHODS
+
+=head2 new
+
+=head2 set_values
+
+=head2 channel
+
+=head2 image
+
+=head2 textinput
+
+=head2 add_item
+
+=head1 AUTHOR
+
+Copyright (c) 2005 Daisuke Maki E<lt>dmaki@cpan.orgE<gt>.
+Development partially funded by Brazil, Ltd. E<lt>http://b.razil.jpE<gt>
+
+=cut
