@@ -194,4 +194,34 @@ sub _populate_extra_modules
     }
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 NAME
+
+XML::RS::LibXML::V10 - Format XML::RSS::LibXML in RSS 1.0 Format
+
+=head1 SYNOPSIS
+
+  use XML::RSS::LibXML;
+  use XML::RSS::LibXML::V10;
+
+  my $rss = XML::RSS::LibXML->new();
+  # populate $rss...
+
+  my $fmt = XML::RSS::LibXML::V10->new;
+  print $fmt->format($rss);
+
+=head1 METHODS
+
+=head2 new
+
+=head2 format
+
+=head1 AUTHOR
+
+Copyright (c) 2005 Daisuke Maki E<lt>dmaki@cpan.orgE<gt>.
+Development partially funded by Brazil, Ltd. E<lt>http://b.razil.jpE<gt>
+
+=cut
