@@ -1,4 +1,4 @@
-# $Id: V20.pm 18 2005-08-17 10:20:53Z daisuke $
+# $Id: V20.pm 20 2005-10-18 09:41:09Z daisuke $
 #
 # Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -156,4 +156,35 @@ sub format
     $xml->toString($format, 1);
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 NAME
+
+XML::RS::LibXML::V20 - Format XML::RSS::LibXML in RSS 2.0 Format
+
+=head1 SYNOPSIS
+
+  use XML::RSS::LibXML;
+  use XML::RSS::LibXML::V20;
+
+  my $rss = XML::RSS::LibXML->new();
+  # populate $rss...
+
+  my $fmt = XML::RSS::LibXML::V20->new;
+  print $fmt->format($rss);
+
+=head1 METHODS
+
+=head2 new
+
+=head2 format
+
+=head1 AUTHOR
+
+Copyright (c) 2005 Daisuke Maki E<lt>dmaki@cpan.orgE<gt>.
+Development partially funded by Brazil, Ltd. E<lt>http://b.razil.jpE<gt>
+
+=cut
+
